# Spyraio 
## Suite Python for Forecasting lightning
**SpyRaio** is a Python package which provide utils for preprocessing, processing and postprocessing severe weather data. The package also provide functions for lightning forecasting.

### Instalation
```console
pip install spyraio
```
### Uninstall
```console
pip uninstall spyraio
```
### Credits
```
  ____                        _
 / ___| _ __  _   _ _ __ __ _(_) ___
 \___ \| '_ \| | | | '__/ _` | |/ _ \
  ___) | |_) | |_| | | | (_| | | (_) |
 |____/| .__/ \__, |_|  \__,_|_|\___/
       |_|    |___/
                 By Adriano P. Almeida
				                 2019
```

